Class: SongtradrApiClientRuby::InternalApiApi
- Inherits:
-
Object
- Object
- SongtradrApiClientRuby::InternalApiApi
- Defined in:
- lib/songtradr_api_client_ruby/api/internal_api_api.rb
Instance Attribute Summary collapse
-
#api_client ⇒ Object
Returns the value of attribute api_client.
Instance Method Summary collapse
-
#initialize(api_client = ApiClient.default) ⇒ InternalApiApi
constructor
A new instance of InternalApiApi.
- #internal_create_inference(authorization, save_file_recording_dto, opts = {}) ⇒ Object
-
#internal_create_inference_with_http_info(authorization, save_file_recording_dto, opts = {}) ⇒ Array<(Object, Integer, Hash)>
Object data, response status code and response headers.
- #internal_update_file(customer_name, object_key, save_file_dto, opts = {}) ⇒ Object
-
#internal_update_file_with_http_info(customer_name, object_key, save_file_dto, opts = {}) ⇒ Array<(Object, Integer, Hash)>
Object data, response status code and response headers.
Constructor Details
#initialize(api_client = ApiClient.default) ⇒ InternalApiApi
Returns a new instance of InternalApiApi.
19 20 21 |
# File 'lib/songtradr_api_client_ruby/api/internal_api_api.rb', line 19 def initialize(api_client = ApiClient.default) @api_client = api_client end |
Instance Attribute Details
#api_client ⇒ Object
Returns the value of attribute api_client.
17 18 19 |
# File 'lib/songtradr_api_client_ruby/api/internal_api_api.rb', line 17 def api_client @api_client end |
Instance Method Details
#internal_create_inference(authorization, save_file_recording_dto, opts = {}) ⇒ Object
26 27 28 29 |
# File 'lib/songtradr_api_client_ruby/api/internal_api_api.rb', line 26 def internal_create_inference(, save_file_recording_dto, opts = {}) data, _status_code, _headers = internal_create_inference_with_http_info(, save_file_recording_dto, opts) data end |
#internal_create_inference_with_http_info(authorization, save_file_recording_dto, opts = {}) ⇒ Array<(Object, Integer, Hash)>
Returns Object data, response status code and response headers.
35 36 37 38 39 40 41 42 43 44 45 46 47 48 49 50 51 52 53 54 55 56 57 58 59 60 61 62 63 64 65 66 67 68 69 70 71 72 73 74 75 76 77 78 79 80 81 82 83 84 85 86 87 88 89 90 91 |
# File 'lib/songtradr_api_client_ruby/api/internal_api_api.rb', line 35 def internal_create_inference_with_http_info(, save_file_recording_dto, opts = {}) if @api_client.config.debugging @api_client.config.logger.debug 'Calling API: InternalApiApi.internal_create_inference ...' end # verify the required parameter 'authorization' is set if @api_client.config.client_side_validation && .nil? fail ArgumentError, "Missing the required parameter 'authorization' when calling InternalApiApi.internal_create_inference" end # verify the required parameter 'save_file_recording_dto' is set if @api_client.config.client_side_validation && save_file_recording_dto.nil? fail ArgumentError, "Missing the required parameter 'save_file_recording_dto' when calling InternalApiApi.internal_create_inference" end # resource path local_var_path = '/api/v1/internal/inference' # query parameters query_params = opts[:query_params] || {} # header parameters header_params = opts[:header_params] || {} # HTTP header 'Accept' (if needed) header_params['Accept'] = @api_client.select_header_accept(['application/json']) # HTTP header 'Content-Type' content_type = @api_client.select_header_content_type(['application/json']) if !content_type.nil? header_params['Content-Type'] = content_type end header_params[:'Authorization'] = # form parameters form_params = opts[:form_params] || {} # http body (model) post_body = opts[:debug_body] || @api_client.object_to_http_body(save_file_recording_dto) # return_type return_type = opts[:debug_return_type] || 'Object' # auth_names auth_names = opts[:debug_auth_names] || ['bearer-jwt'] = opts.merge( :operation => :"InternalApiApi.internal_create_inference", :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => return_type ) data, status_code, headers = @api_client.call_api(:POST, local_var_path, ) if @api_client.config.debugging @api_client.config.logger.debug "API called: InternalApiApi#internal_create_inference\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |
#internal_update_file(customer_name, object_key, save_file_dto, opts = {}) ⇒ Object
98 99 100 101 |
# File 'lib/songtradr_api_client_ruby/api/internal_api_api.rb', line 98 def internal_update_file(customer_name, object_key, save_file_dto, opts = {}) data, _status_code, _headers = internal_update_file_with_http_info(customer_name, object_key, save_file_dto, opts) data end |
#internal_update_file_with_http_info(customer_name, object_key, save_file_dto, opts = {}) ⇒ Array<(Object, Integer, Hash)>
Returns Object data, response status code and response headers.
108 109 110 111 112 113 114 115 116 117 118 119 120 121 122 123 124 125 126 127 128 129 130 131 132 133 134 135 136 137 138 139 140 141 142 143 144 145 146 147 148 149 150 151 152 153 154 155 156 157 158 159 160 161 162 163 164 165 166 167 |
# File 'lib/songtradr_api_client_ruby/api/internal_api_api.rb', line 108 def internal_update_file_with_http_info(customer_name, object_key, save_file_dto, opts = {}) if @api_client.config.debugging @api_client.config.logger.debug 'Calling API: InternalApiApi.internal_update_file ...' end # verify the required parameter 'customer_name' is set if @api_client.config.client_side_validation && customer_name.nil? fail ArgumentError, "Missing the required parameter 'customer_name' when calling InternalApiApi.internal_update_file" end # verify the required parameter 'object_key' is set if @api_client.config.client_side_validation && object_key.nil? fail ArgumentError, "Missing the required parameter 'object_key' when calling InternalApiApi.internal_update_file" end # verify the required parameter 'save_file_dto' is set if @api_client.config.client_side_validation && save_file_dto.nil? fail ArgumentError, "Missing the required parameter 'save_file_dto' when calling InternalApiApi.internal_update_file" end # resource path local_var_path = '/api/v1/internal/file/{customerName}/{objectKey}'.sub('{' + 'customerName' + '}', CGI.escape(customer_name.to_s)).sub('{' + 'objectKey' + '}', CGI.escape(object_key.to_s)) # query parameters query_params = opts[:query_params] || {} # header parameters header_params = opts[:header_params] || {} # HTTP header 'Accept' (if needed) header_params['Accept'] = @api_client.select_header_accept(['application/json']) # HTTP header 'Content-Type' content_type = @api_client.select_header_content_type(['application/json']) if !content_type.nil? header_params['Content-Type'] = content_type end # form parameters form_params = opts[:form_params] || {} # http body (model) post_body = opts[:debug_body] || @api_client.object_to_http_body(save_file_dto) # return_type return_type = opts[:debug_return_type] || 'Object' # auth_names auth_names = opts[:debug_auth_names] || ['bearer-jwt'] = opts.merge( :operation => :"InternalApiApi.internal_update_file", :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => return_type ) data, status_code, headers = @api_client.call_api(:PATCH, local_var_path, ) if @api_client.config.debugging @api_client.config.logger.debug "API called: InternalApiApi#internal_update_file\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |