Class: SongtradrApiClientRuby::PlaylistApi

Inherits:
Object
  • Object
show all
Defined in:
lib/songtradr_api_client_ruby/api/playlist_api.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(api_client = ApiClient.default) ⇒ PlaylistApi

Returns a new instance of PlaylistApi.



19
20
21
# File 'lib/songtradr_api_client_ruby/api/playlist_api.rb', line 19

def initialize(api_client = ApiClient.default)
  @api_client = api_client
end

Instance Attribute Details

#api_clientObject

Returns the value of attribute api_client.



17
18
19
# File 'lib/songtradr_api_client_ruby/api/playlist_api.rb', line 17

def api_client
  @api_client
end

Instance Method Details

#all_playlists(opts = {}) ⇒ Array<PlaylistLargeDTO>

All playlists.

Parameters:

  • opts (Hash) (defaults to: {})

    the optional parameters

Options Hash (opts):

  • :include_recordings (Boolean)

    Whether a playlist shall include recordings or not. (default to false)

  • :ignore_usages (Boolean)

    Whether a playlist shall include all songs regardless of their track usages. (default to false)

  • :usage_filter_mode (String)

    Whether a playlist recordings shall include all playlist usages or not. (default to 'any')

  • :songtradr_playlist_guid (String)

Returns:



29
30
31
32
# File 'lib/songtradr_api_client_ruby/api/playlist_api.rb', line 29

def all_playlists(opts = {})
  data, _status_code, _headers = all_playlists_with_http_info(opts)
  data
end

#all_playlists_with_http_info(opts = {}) ⇒ Array<(Array<PlaylistLargeDTO>, Integer, Hash)>

All playlists.

Parameters:

  • opts (Hash) (defaults to: {})

    the optional parameters

Options Hash (opts):

  • :include_recordings (Boolean)

    Whether a playlist shall include recordings or not. (default to false)

  • :ignore_usages (Boolean)

    Whether a playlist shall include all songs regardless of their track usages. (default to false)

  • :usage_filter_mode (String)

    Whether a playlist recordings shall include all playlist usages or not. (default to 'any')

  • :songtradr_playlist_guid (String)

Returns:

  • (Array<(Array<PlaylistLargeDTO>, Integer, Hash)>)

    Array data, response status code and response headers



41
42
43
44
45
46
47
48
49
50
51
52
53
54
55
56
57
58
59
60
61
62
63
64
65
66
67
68
69
70
71
72
73
74
75
76
77
78
79
80
81
82
83
84
85
86
87
88
89
90
91
# File 'lib/songtradr_api_client_ruby/api/playlist_api.rb', line 41

def all_playlists_with_http_info(opts = {})
  if @api_client.config.debugging
    @api_client.config.logger.debug 'Calling API: PlaylistApi.all_playlists ...'
  end
  allowable_values = ["any", "all"]
  if @api_client.config.client_side_validation && opts[:'usage_filter_mode'] && !allowable_values.include?(opts[:'usage_filter_mode'])
    fail ArgumentError, "invalid value for \"usage_filter_mode\", must be one of #{allowable_values}"
  end
  # resource path
  local_var_path = '/api/v1/playlist'

  # query parameters
  query_params = opts[:query_params] || {}
  query_params[:'includeRecordings'] = opts[:'include_recordings'] if !opts[:'include_recordings'].nil?
  query_params[:'ignoreUsages'] = opts[:'ignore_usages'] if !opts[:'ignore_usages'].nil?
  query_params[:'usageFilterMode'] = opts[:'usage_filter_mode'] if !opts[:'usage_filter_mode'].nil?
  query_params[:'songtradrPlaylistGuid'] = opts[:'songtradr_playlist_guid'] if !opts[:'songtradr_playlist_guid'].nil?

  # header parameters
  header_params = opts[:header_params] || {}
  # HTTP header 'Accept' (if needed)
  header_params['Accept'] = @api_client.select_header_accept(['application/json'])

  # form parameters
  form_params = opts[:form_params] || {}

  # http body (model)
  post_body = opts[:debug_body]

  # return_type
  return_type = opts[:debug_return_type] || 'Array<PlaylistLargeDTO>'

  # auth_names
  auth_names = opts[:debug_auth_names] || ['bearer-jwt']

  new_options = opts.merge(
    :operation => :"PlaylistApi.all_playlists",
    :header_params => header_params,
    :query_params => query_params,
    :form_params => form_params,
    :body => post_body,
    :auth_names => auth_names,
    :return_type => return_type
  )

  data, status_code, headers = @api_client.call_api(:GET, local_var_path, new_options)
  if @api_client.config.debugging
    @api_client.config.logger.debug "API called: PlaylistApi#all_playlists\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}"
  end
  return data, status_code, headers
end

#create_or_update_playlist(save_playlist_dto, opts = {}) ⇒ Object

Create and edit playlist. This endpoint expects always the full amount of information including all recordings.

Parameters:

  • save_playlist_dto (SavePlaylistDTO)
  • opts (Hash) (defaults to: {})

    the optional parameters

Returns:

  • (Object)


98
99
100
101
# File 'lib/songtradr_api_client_ruby/api/playlist_api.rb', line 98

def create_or_update_playlist(save_playlist_dto, opts = {})
  data, _status_code, _headers = create_or_update_playlist_with_http_info(save_playlist_dto, opts)
  data
end

#create_or_update_playlist_with_http_info(save_playlist_dto, opts = {}) ⇒ Array<(Object, Integer, Hash)>

Create and edit playlist. This endpoint expects always the full amount of information including all recordings.

Parameters:

  • save_playlist_dto (SavePlaylistDTO)
  • opts (Hash) (defaults to: {})

    the optional parameters

Returns:

  • (Array<(Object, Integer, Hash)>)

    Object data, response status code and response headers



108
109
110
111
112
113
114
115
116
117
118
119
120
121
122
123
124
125
126
127
128
129
130
131
132
133
134
135
136
137
138
139
140
141
142
143
144
145
146
147
148
149
150
151
152
153
154
155
156
157
158
159
# File 'lib/songtradr_api_client_ruby/api/playlist_api.rb', line 108

def create_or_update_playlist_with_http_info(save_playlist_dto, opts = {})
  if @api_client.config.debugging
    @api_client.config.logger.debug 'Calling API: PlaylistApi.create_or_update_playlist ...'
  end
  # verify the required parameter 'save_playlist_dto' is set
  if @api_client.config.client_side_validation && save_playlist_dto.nil?
    fail ArgumentError, "Missing the required parameter 'save_playlist_dto' when calling PlaylistApi.create_or_update_playlist"
  end
  # resource path
  local_var_path = '/api/v1/playlist'

  # query parameters
  query_params = opts[:query_params] || {}

  # header parameters
  header_params = opts[:header_params] || {}
  # HTTP header 'Accept' (if needed)
  header_params['Accept'] = @api_client.select_header_accept(['application/json'])
  # HTTP header 'Content-Type'
  content_type = @api_client.select_header_content_type(['application/json'])
  if !content_type.nil?
      header_params['Content-Type'] = content_type
  end

  # form parameters
  form_params = opts[:form_params] || {}

  # http body (model)
  post_body = opts[:debug_body] || @api_client.object_to_http_body(save_playlist_dto)

  # return_type
  return_type = opts[:debug_return_type] || 'Object'

  # auth_names
  auth_names = opts[:debug_auth_names] || ['bearer-jwt']

  new_options = opts.merge(
    :operation => :"PlaylistApi.create_or_update_playlist",
    :header_params => header_params,
    :query_params => query_params,
    :form_params => form_params,
    :body => post_body,
    :auth_names => auth_names,
    :return_type => return_type
  )

  data, status_code, headers = @api_client.call_api(:POST, local_var_path, new_options)
  if @api_client.config.debugging
    @api_client.config.logger.debug "API called: PlaylistApi#create_or_update_playlist\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}"
  end
  return data, status_code, headers
end

#delete_playlist(songtradr_playlist_guid, opts = {}) ⇒ Object

Delete playlist.

Parameters:

  • songtradr_playlist_guid (String)

    ID of the file that should be deleted.

  • opts (Hash) (defaults to: {})

    the optional parameters

Returns:

  • (Object)


165
166
167
168
# File 'lib/songtradr_api_client_ruby/api/playlist_api.rb', line 165

def delete_playlist(songtradr_playlist_guid, opts = {})
  data, _status_code, _headers = delete_playlist_with_http_info(songtradr_playlist_guid, opts)
  data
end

#delete_playlist_with_http_info(songtradr_playlist_guid, opts = {}) ⇒ Array<(Object, Integer, Hash)>

Delete playlist.

Parameters:

  • songtradr_playlist_guid (String)

    ID of the file that should be deleted.

  • opts (Hash) (defaults to: {})

    the optional parameters

Returns:

  • (Array<(Object, Integer, Hash)>)

    Object data, response status code and response headers



174
175
176
177
178
179
180
181
182
183
184
185
186
187
188
189
190
191
192
193
194
195
196
197
198
199
200
201
202
203
204
205
206
207
208
209
210
211
212
213
214
215
216
217
218
219
220
# File 'lib/songtradr_api_client_ruby/api/playlist_api.rb', line 174

def delete_playlist_with_http_info(songtradr_playlist_guid, opts = {})
  if @api_client.config.debugging
    @api_client.config.logger.debug 'Calling API: PlaylistApi.delete_playlist ...'
  end
  # verify the required parameter 'songtradr_playlist_guid' is set
  if @api_client.config.client_side_validation && songtradr_playlist_guid.nil?
    fail ArgumentError, "Missing the required parameter 'songtradr_playlist_guid' when calling PlaylistApi.delete_playlist"
  end
  # resource path
  local_var_path = '/api/v1/playlist/{songtradrPlaylistGuid}'.sub('{' + 'songtradrPlaylistGuid' + '}', CGI.escape(songtradr_playlist_guid.to_s))

  # query parameters
  query_params = opts[:query_params] || {}

  # header parameters
  header_params = opts[:header_params] || {}
  # HTTP header 'Accept' (if needed)
  header_params['Accept'] = @api_client.select_header_accept(['application/hal+json', 'application/json'])

  # form parameters
  form_params = opts[:form_params] || {}

  # http body (model)
  post_body = opts[:debug_body]

  # return_type
  return_type = opts[:debug_return_type] || 'Object'

  # auth_names
  auth_names = opts[:debug_auth_names] || ['bearer-jwt']

  new_options = opts.merge(
    :operation => :"PlaylistApi.delete_playlist",
    :header_params => header_params,
    :query_params => query_params,
    :form_params => form_params,
    :body => post_body,
    :auth_names => auth_names,
    :return_type => return_type
  )

  data, status_code, headers = @api_client.call_api(:DELETE, local_var_path, new_options)
  if @api_client.config.debugging
    @api_client.config.logger.debug "API called: PlaylistApi#delete_playlist\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}"
  end
  return data, status_code, headers
end