Class: SongtradrApiClientRuby::RecordingMediumDTO

Inherits:
Object
  • Object
show all
Defined in:
lib/songtradr_api_client_ruby/models/recording_medium_dto.rb

Overview

Recording with a mid-sized field set.

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(attributes = {}) ⇒ RecordingMediumDTO

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash



88
89
90
91
92
93
94
95
96
97
98
99
100
101
102
103
104
105
106
107
108
109
110
111
112
113
114
115
116
117
118
119
120
121
122
123
124
125
126
127
128
129
130
131
132
133
134
135
136
137
138
139
140
141
142
143
144
145
146
147
148
149
150
151
152
153
154
155
156
157
158
# File 'lib/songtradr_api_client_ruby/models/recording_medium_dto.rb', line 88

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    fail ArgumentError, "The input argument (attributes) must be a hash in `SongtradrApiClientRuby::RecordingMediumDTO` initialize method"
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!self.class.attribute_map.key?(k.to_sym))
      fail ArgumentError, "`#{k}` is not a valid attribute in `SongtradrApiClientRuby::RecordingMediumDTO`. Please check the name to make sure it's valid. List of attributes: " + self.class.attribute_map.keys.inspect
    end
    h[k.to_sym] = v
  }

  if attributes.key?(:'isrc')
    self.isrc = attributes[:'isrc']
  else
    self.isrc = nil
  end

  if attributes.key?(:'recording_party_entities')
    if (value = attributes[:'recording_party_entities']).is_a?(Array)
      self.recording_party_entities = value
    end
  end

  if attributes.key?(:'genres')
    if (value = attributes[:'genres']).is_a?(Array)
      self.genres = value
    end
  end

  if attributes.key?(:'language_of_performance')
    self.language_of_performance = attributes[:'language_of_performance']
  end

  if attributes.key?(:'release_date')
    self.release_date = attributes[:'release_date']
  end

  if attributes.key?(:'titles')
    if (value = attributes[:'titles']).is_a?(Array)
      self.titles = value
    end
  end

  if attributes.key?(:'tracks')
    if (value = attributes[:'tracks']).is_a?(Array)
      self.tracks = value
    end
  end

  if attributes.key?(:'musical_features')
    self.musical_features = attributes[:'musical_features']
  end

  if attributes.key?(:'spotify_id')
    self.spotify_id = attributes[:'spotify_id']
  end

  if attributes.key?(:'tags')
    if (value = attributes[:'tags']).is_a?(Array)
      self.tags = value
    end
  end

  if attributes.key?(:'genre_predictions')
    if (value = attributes[:'genre_predictions']).is_a?(Array)
      self.genre_predictions = value
    end
  end
end

Instance Attribute Details

#genre_predictionsObject

Returns the value of attribute genre_predictions.



39
40
41
# File 'lib/songtradr_api_client_ruby/models/recording_medium_dto.rb', line 39

def genre_predictions
  @genre_predictions
end

#genresObject

Returns the value of attribute genres.



23
24
25
# File 'lib/songtradr_api_client_ruby/models/recording_medium_dto.rb', line 23

def genres
  @genres
end

#isrcObject

Returns the value of attribute isrc.



19
20
21
# File 'lib/songtradr_api_client_ruby/models/recording_medium_dto.rb', line 19

def isrc
  @isrc
end

#language_of_performanceObject

Returns the value of attribute language_of_performance.



25
26
27
# File 'lib/songtradr_api_client_ruby/models/recording_medium_dto.rb', line 25

def language_of_performance
  @language_of_performance
end

#musical_featuresObject

Returns the value of attribute musical_features.



33
34
35
# File 'lib/songtradr_api_client_ruby/models/recording_medium_dto.rb', line 33

def musical_features
  @musical_features
end

#recording_party_entitiesObject

Returns the value of attribute recording_party_entities.



21
22
23
# File 'lib/songtradr_api_client_ruby/models/recording_medium_dto.rb', line 21

def recording_party_entities
  @recording_party_entities
end

#release_dateObject

Returns the value of attribute release_date.



27
28
29
# File 'lib/songtradr_api_client_ruby/models/recording_medium_dto.rb', line 27

def release_date
  @release_date
end

#spotify_idObject

Returns the value of attribute spotify_id.



35
36
37
# File 'lib/songtradr_api_client_ruby/models/recording_medium_dto.rb', line 35

def spotify_id
  @spotify_id
end

#tagsObject

Returns the value of attribute tags.



37
38
39
# File 'lib/songtradr_api_client_ruby/models/recording_medium_dto.rb', line 37

def tags
  @tags
end

#titlesObject

Returns the value of attribute titles.



29
30
31
# File 'lib/songtradr_api_client_ruby/models/recording_medium_dto.rb', line 29

def titles
  @titles
end

#tracksObject

Returns the value of attribute tracks.



31
32
33
# File 'lib/songtradr_api_client_ruby/models/recording_medium_dto.rb', line 31

def tracks
  @tracks
end

Class Method Details

._deserialize(type, value) ⇒ Object

Deserializes the data based on type

Parameters:

  • string

    type Data type

  • string

    value Value to be deserialized

Returns:

  • (Object)

    Deserialized data



277
278
279
280
281
282
283
284
285
286
287
288
289
290
291
292
293
294
295
296
297
298
299
300
301
302
303
304
305
306
307
308
309
310
311
312
313
314
# File 'lib/songtradr_api_client_ruby/models/recording_medium_dto.rb', line 277

def self._deserialize(type, value)
  case type.to_sym
  when :Time
    Time.parse(value)
  when :Date
    Date.parse(value)
  when :String
    value.to_s
  when :Integer
    value.to_i
  when :Float
    value.to_f
  when :Boolean
    if value.to_s =~ /\A(true|t|yes|y|1)\z/i
      true
    else
      false
    end
  when :Object
    # generic object (usually a Hash), return directly
    value
  when /\AArray<(?<inner_type>.+)>\z/
    inner_type = Regexp.last_match[:inner_type]
    value.map { |v| _deserialize(inner_type, v) }
  when /\AHash<(?<k_type>.+?), (?<v_type>.+)>\z/
    k_type = Regexp.last_match[:k_type]
    v_type = Regexp.last_match[:v_type]
    {}.tap do |hash|
      value.each do |k, v|
        hash[_deserialize(k_type, k)] = _deserialize(v_type, v)
      end
    end
  else # model
    # models (e.g. Pet) or oneOf
    klass = SongtradrApiClientRuby.const_get(type)
    klass.respond_to?(:openapi_any_of) || klass.respond_to?(:openapi_one_of) ? klass.build(value) : klass.build_from_hash(value)
  end
end

.acceptable_attributesObject

Returns all the JSON keys this model knows about



59
60
61
# File 'lib/songtradr_api_client_ruby/models/recording_medium_dto.rb', line 59

def self.acceptable_attributes
  attribute_map.values
end

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



42
43
44
45
46
47
48
49
50
51
52
53
54
55
56
# File 'lib/songtradr_api_client_ruby/models/recording_medium_dto.rb', line 42

def self.attribute_map
  {
    :'isrc' => :'isrc',
    :'recording_party_entities' => :'recordingPartyEntities',
    :'genres' => :'genres',
    :'language_of_performance' => :'languageOfPerformance',
    :'release_date' => :'releaseDate',
    :'titles' => :'titles',
    :'tracks' => :'tracks',
    :'musical_features' => :'musicalFeatures',
    :'spotify_id' => :'spotifyId',
    :'tags' => :'tags',
    :'genre_predictions' => :'genrePredictions'
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



253
254
255
256
257
258
259
260
261
262
263
264
265
266
267
268
269
270
271
# File 'lib/songtradr_api_client_ruby/models/recording_medium_dto.rb', line 253

def self.build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  attributes = attributes.transform_keys(&:to_sym)
  transformed_hash = {}
  openapi_types.each_pair do |key, type|
    if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = nil
    elsif type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[attribute_map[key]].is_a?(Array)
        transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) }
      end
    elsif !attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]])
    end
  end
  new(transformed_hash)
end

.openapi_nullableObject

List of attributes with nullable: true



81
82
83
84
# File 'lib/songtradr_api_client_ruby/models/recording_medium_dto.rb', line 81

def self.openapi_nullable
  Set.new([
  ])
end

.openapi_typesObject

Attribute type mapping.



64
65
66
67
68
69
70
71
72
73
74
75
76
77
78
# File 'lib/songtradr_api_client_ruby/models/recording_medium_dto.rb', line 64

def self.openapi_types
  {
    :'isrc' => :'String',
    :'recording_party_entities' => :'Array<RecordingPartyDTO>',
    :'genres' => :'Array<GenreDTO>',
    :'language_of_performance' => :'String',
    :'release_date' => :'Time',
    :'titles' => :'Array<TitleDTO>',
    :'tracks' => :'Array<TrackDTO>',
    :'musical_features' => :'MusicalFeaturesDTO',
    :'spotify_id' => :'String',
    :'tags' => :'Array<RecordingTagSmallDTO>',
    :'genre_predictions' => :'Array<RecordingGenrePredictionDTO>'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object)

    to be compared



222
223
224
225
226
227
228
229
230
231
232
233
234
235
236
# File 'lib/songtradr_api_client_ruby/models/recording_medium_dto.rb', line 222

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      isrc == o.isrc &&
      recording_party_entities == o.recording_party_entities &&
      genres == o.genres &&
      language_of_performance == o.language_of_performance &&
      release_date == o.release_date &&
      titles == o.titles &&
      tracks == o.tracks &&
      musical_features == o.musical_features &&
      spotify_id == o.spotify_id &&
      tags == o.tags &&
      genre_predictions == o.genre_predictions
end

#_to_hash(value) ⇒ Hash

Outputs non-array value in the form of hash For object, use to_hash. Otherwise, just return the value

Parameters:

  • value (Object)

    Any valid value

Returns:

  • (Hash)

    Returns the value in the form of hash



348
349
350
351
352
353
354
355
356
357
358
359
360
# File 'lib/songtradr_api_client_ruby/models/recording_medium_dto.rb', line 348

def _to_hash(value)
  if value.is_a?(Array)
    value.compact.map { |v| _to_hash(v) }
  elsif value.is_a?(Hash)
    {}.tap do |hash|
      value.each { |k, v| hash[k] = _to_hash(v) }
    end
  elsif value.respond_to? :to_hash
    value.to_hash
  else
    value
  end
end

#eql?(o) ⇒ Boolean

Parameters:

  • Object (Object)

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


240
241
242
# File 'lib/songtradr_api_client_ruby/models/recording_medium_dto.rb', line 240

def eql?(o)
  self == o
end

#hashInteger

Calculates hash code according to all attributes.

Returns:

  • (Integer)

    Hash code



246
247
248
# File 'lib/songtradr_api_client_ruby/models/recording_medium_dto.rb', line 246

def hash
  [isrc, recording_party_entities, genres, language_of_performance, release_date, titles, tracks, musical_features, spotify_id, tags, genre_predictions].hash
end

#list_invalid_propertiesObject

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properties with the reasons



162
163
164
165
166
167
168
169
170
# File 'lib/songtradr_api_client_ruby/models/recording_medium_dto.rb', line 162

def list_invalid_properties
  warn '[DEPRECATED] the `list_invalid_properties` method is obsolete'
  invalid_properties = Array.new
  if @isrc.nil?
    invalid_properties.push('invalid value for "isrc", isrc cannot be nil.')
  end

  invalid_properties
end

#to_bodyHash

to_body is an alias to to_hash (backward compatibility)

Returns:

  • (Hash)

    Returns the object in the form of hash



324
325
326
# File 'lib/songtradr_api_client_ruby/models/recording_medium_dto.rb', line 324

def to_body
  to_hash
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



330
331
332
333
334
335
336
337
338
339
340
341
342
# File 'lib/songtradr_api_client_ruby/models/recording_medium_dto.rb', line 330

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    if value.nil?
      is_nullable = self.class.openapi_nullable.include?(attr)
      next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}"))
    end

    hash[param] = _to_hash(value)
  end
  hash
end

#to_sString

Returns the string representation of the object

Returns:

  • (String)

    String presentation of the object



318
319
320
# File 'lib/songtradr_api_client_ruby/models/recording_medium_dto.rb', line 318

def to_s
  to_hash.to_s
end

#valid?Boolean

Check to see if the all the properties in the model are valid

Returns:

  • (Boolean)

    true if the model is valid



174
175
176
177
178
# File 'lib/songtradr_api_client_ruby/models/recording_medium_dto.rb', line 174

def valid?
  warn '[DEPRECATED] the `valid?` method is obsolete'
  return false if @isrc.nil?
  true
end