Class: SongtradrApiClientRuby::SaveUserDTO

Inherits:
Object
  • Object
show all
Defined in:
lib/songtradr_api_client_ruby/models/save_user_dto.rb

Overview

Credentials for sign-up to musicube the API and Website.

Defined Under Namespace

Classes: EnumAttributeValidator

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(attributes = {}) ⇒ SaveUserDTO

Initializes the object



91
92
93
94
95
96
97
98
99
100
101
102
103
104
105
106
107
108
109
110
111
112
113
114
115
116
117
118
119
120
121
122
123
124
125
126
127
128
129
# File 'lib/songtradr_api_client_ruby/models/save_user_dto.rb', line 91

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    fail ArgumentError, "The input argument (attributes) must be a hash in `SongtradrApiClientRuby::SaveUserDTO` initialize method"
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!self.class.attribute_map.key?(k.to_sym))
      fail ArgumentError, "`#{k}` is not a valid attribute in `SongtradrApiClientRuby::SaveUserDTO`. Please check the name to make sure it's valid. List of attributes: " + self.class.attribute_map.keys.inspect
    end
    h[k.to_sym] = v
  }

  if attributes.key?(:'system')
    self.system = attributes[:'system']
  end

  if attributes.key?(:'email_address')
    self.email_address = attributes[:'email_address']
  else
    self.email_address = nil
  end

  if attributes.key?(:'password')
    self.password = attributes[:'password']
  end

  if attributes.key?(:'full_name')
    self.full_name = attributes[:'full_name']
  end

  if attributes.key?(:'company_name')
    self.company_name = attributes[:'company_name']
  end

  if attributes.key?(:'language')
    self.language = attributes[:'language']
  end
end

Instance Attribute Details

#company_nameObject

Returns the value of attribute company_name.



27
28
29
# File 'lib/songtradr_api_client_ruby/models/save_user_dto.rb', line 27

def company_name
  @company_name
end

#email_addressObject

Returns the value of attribute email_address.



21
22
23
# File 'lib/songtradr_api_client_ruby/models/save_user_dto.rb', line 21

def email_address
  @email_address
end

#full_nameObject

Returns the value of attribute full_name.



25
26
27
# File 'lib/songtradr_api_client_ruby/models/save_user_dto.rb', line 25

def full_name
  @full_name
end

#languageObject

Current status of the recording.



30
31
32
# File 'lib/songtradr_api_client_ruby/models/save_user_dto.rb', line 30

def language
  @language
end

#passwordObject

Returns the value of attribute password.



23
24
25
# File 'lib/songtradr_api_client_ruby/models/save_user_dto.rb', line 23

def password
  @password
end

#systemObject

Returns the value of attribute system.



19
20
21
# File 'lib/songtradr_api_client_ruby/models/save_user_dto.rb', line 19

def system
  @system
end

Class Method Details

._deserialize(type, value) ⇒ Object

Deserializes the data based on type



227
228
229
230
231
232
233
234
235
236
237
238
239
240
241
242
243
244
245
246
247
248
249
250
251
252
253
254
255
256
257
258
259
260
261
262
263
264
# File 'lib/songtradr_api_client_ruby/models/save_user_dto.rb', line 227

def self._deserialize(type, value)
  case type.to_sym
  when :Time
    Time.parse(value)
  when :Date
    Date.parse(value)
  when :String
    value.to_s
  when :Integer
    value.to_i
  when :Float
    value.to_f
  when :Boolean
    if value.to_s =~ /\A(true|t|yes|y|1)\z/i
      true
    else
      false
    end
  when :Object
    # generic object (usually a Hash), return directly
    value
  when /\AArray<(?<inner_type>.+)>\z/
    inner_type = Regexp.last_match[:inner_type]
    value.map { |v| _deserialize(inner_type, v) }
  when /\AHash<(?<k_type>.+?), (?<v_type>.+)>\z/
    k_type = Regexp.last_match[:k_type]
    v_type = Regexp.last_match[:v_type]
    {}.tap do |hash|
      value.each do |k, v|
        hash[_deserialize(k_type, k)] = _deserialize(v_type, v)
      end
    end
  else # model
    # models (e.g. Pet) or oneOf
    klass = SongtradrApiClientRuby.const_get(type)
    klass.respond_to?(:openapi_any_of) || klass.respond_to?(:openapi_one_of) ? klass.build(value) : klass.build_from_hash(value)
  end
end

.acceptable_attributesObject

Returns all the JSON keys this model knows about



67
68
69
# File 'lib/songtradr_api_client_ruby/models/save_user_dto.rb', line 67

def self.acceptable_attributes
  attribute_map.values
end

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



55
56
57
58
59
60
61
62
63
64
# File 'lib/songtradr_api_client_ruby/models/save_user_dto.rb', line 55

def self.attribute_map
  {
    :'system' => :'system',
    :'email_address' => :'emailAddress',
    :'password' => :'password',
    :'full_name' => :'fullName',
    :'company_name' => :'companyName',
    :'language' => :'language'
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash



203
204
205
206
207
208
209
210
211
212
213
214
215
216
217
218
219
220
221
# File 'lib/songtradr_api_client_ruby/models/save_user_dto.rb', line 203

def self.build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  attributes = attributes.transform_keys(&:to_sym)
  transformed_hash = {}
  openapi_types.each_pair do |key, type|
    if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = nil
    elsif type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[attribute_map[key]].is_a?(Array)
        transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) }
      end
    elsif !attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]])
    end
  end
  new(transformed_hash)
end

.openapi_nullableObject

List of attributes with nullable: true



84
85
86
87
# File 'lib/songtradr_api_client_ruby/models/save_user_dto.rb', line 84

def self.openapi_nullable
  Set.new([
  ])
end

.openapi_typesObject

Attribute type mapping.



72
73
74
75
76
77
78
79
80
81
# File 'lib/songtradr_api_client_ruby/models/save_user_dto.rb', line 72

def self.openapi_types
  {
    :'system' => :'String',
    :'email_address' => :'String',
    :'password' => :'String',
    :'full_name' => :'String',
    :'company_name' => :'String',
    :'language' => :'String'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.



177
178
179
180
181
182
183
184
185
186
# File 'lib/songtradr_api_client_ruby/models/save_user_dto.rb', line 177

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      system == o.system &&
      email_address == o.email_address &&
      password == o.password &&
      full_name == o.full_name &&
      company_name == o.company_name &&
      language == o.language
end

#_to_hash(value) ⇒ Hash

Outputs non-array value in the form of hash For object, use to_hash. Otherwise, just return the value



298
299
300
301
302
303
304
305
306
307
308
309
310
# File 'lib/songtradr_api_client_ruby/models/save_user_dto.rb', line 298

def _to_hash(value)
  if value.is_a?(Array)
    value.compact.map { |v| _to_hash(v) }
  elsif value.is_a?(Hash)
    {}.tap do |hash|
      value.each { |k, v| hash[k] = _to_hash(v) }
    end
  elsif value.respond_to? :to_hash
    value.to_hash
  else
    value
  end
end

#eql?(o) ⇒ Boolean

See Also:

  • `==` method


190
191
192
# File 'lib/songtradr_api_client_ruby/models/save_user_dto.rb', line 190

def eql?(o)
  self == o
end

#hashInteger

Calculates hash code according to all attributes.



196
197
198
# File 'lib/songtradr_api_client_ruby/models/save_user_dto.rb', line 196

def hash
  [system, email_address, password, full_name, company_name, language].hash
end

#list_invalid_propertiesObject

Show invalid properties with the reasons. Usually used together with valid?



133
134
135
136
137
138
139
140
141
# File 'lib/songtradr_api_client_ruby/models/save_user_dto.rb', line 133

def list_invalid_properties
  warn '[DEPRECATED] the `list_invalid_properties` method is obsolete'
  invalid_properties = Array.new
  if @email_address.nil?
    invalid_properties.push('invalid value for "email_address", email_address cannot be nil.')
  end

  invalid_properties
end

#to_bodyHash

to_body is an alias to to_hash (backward compatibility)



274
275
276
# File 'lib/songtradr_api_client_ruby/models/save_user_dto.rb', line 274

def to_body
  to_hash
end

#to_hashHash

Returns the object in the form of hash



280
281
282
283
284
285
286
287
288
289
290
291
292
# File 'lib/songtradr_api_client_ruby/models/save_user_dto.rb', line 280

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    if value.nil?
      is_nullable = self.class.openapi_nullable.include?(attr)
      next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}"))
    end

    hash[param] = _to_hash(value)
  end
  hash
end

#to_sString

Returns the string representation of the object



268
269
270
# File 'lib/songtradr_api_client_ruby/models/save_user_dto.rb', line 268

def to_s
  to_hash.to_s
end

#valid?Boolean

Check to see if the all the properties in the model are valid



145
146
147
148
149
150
151
152
153
# File 'lib/songtradr_api_client_ruby/models/save_user_dto.rb', line 145

def valid?
  warn '[DEPRECATED] the `valid?` method is obsolete'
  system_validator = EnumAttributeValidator.new('String', ["musicube", "cloud"])
  return false unless system_validator.valid?(@system)
  return false if @email_address.nil?
  language_validator = EnumAttributeValidator.new('String', ["en", "de"])
  return false unless language_validator.valid?(@language)
  true
end