Class: SongtradrApiClientRuby::FileSmallDTO
- Inherits:
-
Object
- Object
- SongtradrApiClientRuby::FileSmallDTO
- Defined in:
- lib/songtradr_api_client_ruby/models/file_small_dto.rb
Overview
Reduced details on a file that has been uploaded for auto-tagging or audio-recognition purposes.
Defined Under Namespace
Classes: EnumAttributeValidator
Instance Attribute Summary collapse
-
#error_message ⇒ Object
Returns the value of attribute error_message.
-
#error_time ⇒ Object
Returns the value of attribute error_time.
-
#extension ⇒ Object
extension of the file.
-
#fingerprint_end_time ⇒ Object
Returns the value of attribute fingerprint_end_time.
-
#fingerprint_start_time ⇒ Object
Returns the value of attribute fingerprint_start_time.
-
#fingerprint_status ⇒ Object
status of the audio recognition.
-
#folder ⇒ Object
Returns the value of attribute folder.
-
#id ⇒ Object
Returns the value of attribute id.
-
#inference_end_time ⇒ Object
Returns the value of attribute inference_end_time.
-
#inference_start_time ⇒ Object
Returns the value of attribute inference_start_time.
-
#inference_status ⇒ Object
status of the auto-tagging.
-
#name ⇒ Object
Returns the value of attribute name.
-
#object_key ⇒ Object
Returns the value of attribute object_key.
-
#upload_end_time ⇒ Object
Returns the value of attribute upload_end_time.
-
#upload_start_time ⇒ Object
Returns the value of attribute upload_start_time.
Class Method Summary collapse
-
._deserialize(type, value) ⇒ Object
Deserializes the data based on type.
-
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about.
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.build_from_hash(attributes) ⇒ Object
Builds the object from hash.
-
.openapi_nullable ⇒ Object
List of attributes with nullable: true.
-
.openapi_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(o) ⇒ Object
Checks equality by comparing each attribute.
-
#_to_hash(value) ⇒ Hash
Outputs non-array value in the form of hash For object, use to_hash.
- #eql?(o) ⇒ Boolean
-
#hash ⇒ Integer
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ FileSmallDTO
constructor
Initializes the object.
-
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons.
-
#to_body ⇒ Hash
to_body is an alias to to_hash (backward compatibility).
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#to_s ⇒ String
Returns the string representation of the object.
-
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid.
Constructor Details
#initialize(attributes = {}) ⇒ FileSmallDTO
Initializes the object
129 130 131 132 133 134 135 136 137 138 139 140 141 142 143 144 145 146 147 148 149 150 151 152 153 154 155 156 157 158 159 160 161 162 163 164 165 166 167 168 169 170 171 172 173 174 175 176 177 178 179 180 181 182 183 184 185 186 187 188 189 190 191 192 193 194 195 196 197 198 199 200 201 202 203 204 205 206 207 208 209 210 211 |
# File 'lib/songtradr_api_client_ruby/models/file_small_dto.rb', line 129 def initialize(attributes = {}) if (!attributes.is_a?(Hash)) fail ArgumentError, "The input argument (attributes) must be a hash in `SongtradrApiClientRuby::FileSmallDTO` initialize method" end # check to see if the attribute exists and convert string to symbol for hash key attributes = attributes.each_with_object({}) { |(k, v), h| if (!self.class.attribute_map.key?(k.to_sym)) fail ArgumentError, "`#{k}` is not a valid attribute in `SongtradrApiClientRuby::FileSmallDTO`. Please check the name to make sure it's valid. List of attributes: " + self.class.attribute_map.keys.inspect end h[k.to_sym] = v } if attributes.key?(:'folder') self.folder = attributes[:'folder'] else self.folder = nil end if attributes.key?(:'name') self.name = attributes[:'name'] else self.name = nil end if attributes.key?(:'id') self.id = attributes[:'id'] else self.id = nil end if attributes.key?(:'extension') self.extension = attributes[:'extension'] else self.extension = nil end if attributes.key?(:'error_message') self. = attributes[:'error_message'] end if attributes.key?(:'object_key') self.object_key = attributes[:'object_key'] else self.object_key = nil end if attributes.key?(:'upload_start_time') self.upload_start_time = attributes[:'upload_start_time'] end if attributes.key?(:'upload_end_time') self.upload_end_time = attributes[:'upload_end_time'] end if attributes.key?(:'fingerprint_start_time') self.fingerprint_start_time = attributes[:'fingerprint_start_time'] end if attributes.key?(:'fingerprint_end_time') self.fingerprint_end_time = attributes[:'fingerprint_end_time'] end if attributes.key?(:'inference_status') self.inference_status = attributes[:'inference_status'] end if attributes.key?(:'inference_start_time') self.inference_start_time = attributes[:'inference_start_time'] end if attributes.key?(:'inference_end_time') self.inference_end_time = attributes[:'inference_end_time'] end if attributes.key?(:'error_time') self.error_time = attributes[:'error_time'] end if attributes.key?(:'fingerprint_status') self.fingerprint_status = attributes[:'fingerprint_status'] end end |
Instance Attribute Details
#error_message ⇒ Object
Returns the value of attribute error_message.
28 29 30 |
# File 'lib/songtradr_api_client_ruby/models/file_small_dto.rb', line 28 def @error_message end |
#error_time ⇒ Object
Returns the value of attribute error_time.
47 48 49 |
# File 'lib/songtradr_api_client_ruby/models/file_small_dto.rb', line 47 def error_time @error_time end |
#extension ⇒ Object
extension of the file
26 27 28 |
# File 'lib/songtradr_api_client_ruby/models/file_small_dto.rb', line 26 def extension @extension end |
#fingerprint_end_time ⇒ Object
Returns the value of attribute fingerprint_end_time.
38 39 40 |
# File 'lib/songtradr_api_client_ruby/models/file_small_dto.rb', line 38 def fingerprint_end_time @fingerprint_end_time end |
#fingerprint_start_time ⇒ Object
Returns the value of attribute fingerprint_start_time.
36 37 38 |
# File 'lib/songtradr_api_client_ruby/models/file_small_dto.rb', line 36 def fingerprint_start_time @fingerprint_start_time end |
#fingerprint_status ⇒ Object
status of the audio recognition
50 51 52 |
# File 'lib/songtradr_api_client_ruby/models/file_small_dto.rb', line 50 def fingerprint_status @fingerprint_status end |
#folder ⇒ Object
Returns the value of attribute folder.
19 20 21 |
# File 'lib/songtradr_api_client_ruby/models/file_small_dto.rb', line 19 def folder @folder end |
#id ⇒ Object
Returns the value of attribute id.
23 24 25 |
# File 'lib/songtradr_api_client_ruby/models/file_small_dto.rb', line 23 def id @id end |
#inference_end_time ⇒ Object
Returns the value of attribute inference_end_time.
45 46 47 |
# File 'lib/songtradr_api_client_ruby/models/file_small_dto.rb', line 45 def inference_end_time @inference_end_time end |
#inference_start_time ⇒ Object
Returns the value of attribute inference_start_time.
43 44 45 |
# File 'lib/songtradr_api_client_ruby/models/file_small_dto.rb', line 43 def inference_start_time @inference_start_time end |
#inference_status ⇒ Object
status of the auto-tagging
41 42 43 |
# File 'lib/songtradr_api_client_ruby/models/file_small_dto.rb', line 41 def inference_status @inference_status end |
#name ⇒ Object
Returns the value of attribute name.
21 22 23 |
# File 'lib/songtradr_api_client_ruby/models/file_small_dto.rb', line 21 def name @name end |
#object_key ⇒ Object
Returns the value of attribute object_key.
30 31 32 |
# File 'lib/songtradr_api_client_ruby/models/file_small_dto.rb', line 30 def object_key @object_key end |
#upload_end_time ⇒ Object
Returns the value of attribute upload_end_time.
34 35 36 |
# File 'lib/songtradr_api_client_ruby/models/file_small_dto.rb', line 34 def upload_end_time @upload_end_time end |
#upload_start_time ⇒ Object
Returns the value of attribute upload_start_time.
32 33 34 |
# File 'lib/songtradr_api_client_ruby/models/file_small_dto.rb', line 32 def upload_start_time @upload_start_time end |
Class Method Details
._deserialize(type, value) ⇒ Object
Deserializes the data based on type
350 351 352 353 354 355 356 357 358 359 360 361 362 363 364 365 366 367 368 369 370 371 372 373 374 375 376 377 378 379 380 381 382 383 384 385 386 387 |
# File 'lib/songtradr_api_client_ruby/models/file_small_dto.rb', line 350 def self._deserialize(type, value) case type.to_sym when :Time Time.parse(value) when :Date Date.parse(value) when :String value.to_s when :Integer value.to_i when :Float value.to_f when :Boolean if value.to_s =~ /\A(true|t|yes|y|1)\z/i true else false end when :Object # generic object (usually a Hash), return directly value when /\AArray<(?<inner_type>.+)>\z/ inner_type = Regexp.last_match[:inner_type] value.map { |v| _deserialize(inner_type, v) } when /\AHash<(?<k_type>.+?), (?<v_type>.+)>\z/ k_type = Regexp.last_match[:k_type] v_type = Regexp.last_match[:v_type] {}.tap do |hash| value.each do |k, v| hash[_deserialize(k_type, k)] = _deserialize(v_type, v) end end else # model # models (e.g. Pet) or oneOf klass = SongtradrApiClientRuby.const_get(type) klass.respond_to?(:openapi_any_of) || klass.respond_to?(:openapi_one_of) ? klass.build(value) : klass.build_from_hash(value) end end |
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about
96 97 98 |
# File 'lib/songtradr_api_client_ruby/models/file_small_dto.rb', line 96 def self.acceptable_attributes attribute_map.values end |
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
75 76 77 78 79 80 81 82 83 84 85 86 87 88 89 90 91 92 93 |
# File 'lib/songtradr_api_client_ruby/models/file_small_dto.rb', line 75 def self.attribute_map { :'folder' => :'folder', :'name' => :'name', :'id' => :'id', :'extension' => :'extension', :'error_message' => :'error_message', :'object_key' => :'objectKey', :'upload_start_time' => :'uploadStartTime', :'upload_end_time' => :'uploadEndTime', :'fingerprint_start_time' => :'fingerprintStartTime', :'fingerprint_end_time' => :'fingerprintEndTime', :'inference_status' => :'inferenceStatus', :'inference_start_time' => :'inferenceStartTime', :'inference_end_time' => :'inferenceEndTime', :'error_time' => :'error_time', :'fingerprint_status' => :'fingerprintStatus' } end |
.build_from_hash(attributes) ⇒ Object
Builds the object from hash
326 327 328 329 330 331 332 333 334 335 336 337 338 339 340 341 342 343 344 |
# File 'lib/songtradr_api_client_ruby/models/file_small_dto.rb', line 326 def self.build_from_hash(attributes) return nil unless attributes.is_a?(Hash) attributes = attributes.transform_keys(&:to_sym) transformed_hash = {} openapi_types.each_pair do |key, type| if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = nil elsif type =~ /\AArray<(.*)>/i # check to ensure the input is an array given that the attribute # is documented as an array but the input is not if attributes[attribute_map[key]].is_a?(Array) transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) } end elsif !attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]]) end end new(transformed_hash) end |
.openapi_nullable ⇒ Object
List of attributes with nullable: true
122 123 124 125 |
# File 'lib/songtradr_api_client_ruby/models/file_small_dto.rb', line 122 def self.openapi_nullable Set.new([ ]) end |
.openapi_types ⇒ Object
Attribute type mapping.
101 102 103 104 105 106 107 108 109 110 111 112 113 114 115 116 117 118 119 |
# File 'lib/songtradr_api_client_ruby/models/file_small_dto.rb', line 101 def self.openapi_types { :'folder' => :'String', :'name' => :'String', :'id' => :'Integer', :'extension' => :'String', :'error_message' => :'String', :'object_key' => :'String', :'upload_start_time' => :'Time', :'upload_end_time' => :'Time', :'fingerprint_start_time' => :'Time', :'fingerprint_end_time' => :'Time', :'inference_status' => :'String', :'inference_start_time' => :'Time', :'inference_end_time' => :'Time', :'error_time' => :'Time', :'fingerprint_status' => :'String' } end |
Instance Method Details
#==(o) ⇒ Object
Checks equality by comparing each attribute.
291 292 293 294 295 296 297 298 299 300 301 302 303 304 305 306 307 308 309 |
# File 'lib/songtradr_api_client_ruby/models/file_small_dto.rb', line 291 def ==(o) return true if self.equal?(o) self.class == o.class && folder == o.folder && name == o.name && id == o.id && extension == o.extension && == o. && object_key == o.object_key && upload_start_time == o.upload_start_time && upload_end_time == o.upload_end_time && fingerprint_start_time == o.fingerprint_start_time && fingerprint_end_time == o.fingerprint_end_time && inference_status == o.inference_status && inference_start_time == o.inference_start_time && inference_end_time == o.inference_end_time && error_time == o.error_time && fingerprint_status == o.fingerprint_status end |
#_to_hash(value) ⇒ Hash
Outputs non-array value in the form of hash For object, use to_hash. Otherwise, just return the value
421 422 423 424 425 426 427 428 429 430 431 432 433 |
# File 'lib/songtradr_api_client_ruby/models/file_small_dto.rb', line 421 def _to_hash(value) if value.is_a?(Array) value.compact.map { |v| _to_hash(v) } elsif value.is_a?(Hash) {}.tap do |hash| value.each { |k, v| hash[k] = _to_hash(v) } end elsif value.respond_to? :to_hash value.to_hash else value end end |
#eql?(o) ⇒ Boolean
313 314 315 |
# File 'lib/songtradr_api_client_ruby/models/file_small_dto.rb', line 313 def eql?(o) self == o end |
#hash ⇒ Integer
Calculates hash code according to all attributes.
319 320 321 |
# File 'lib/songtradr_api_client_ruby/models/file_small_dto.rb', line 319 def hash [folder, name, id, extension, , object_key, upload_start_time, upload_end_time, fingerprint_start_time, fingerprint_end_time, inference_status, inference_start_time, inference_end_time, error_time, fingerprint_status].hash end |
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons. Usually used together with valid?
215 216 217 218 219 220 221 222 223 224 225 226 227 228 229 230 231 232 233 234 235 236 237 238 239 |
# File 'lib/songtradr_api_client_ruby/models/file_small_dto.rb', line 215 def list_invalid_properties warn '[DEPRECATED] the `list_invalid_properties` method is obsolete' invalid_properties = Array.new if @folder.nil? invalid_properties.push('invalid value for "folder", folder cannot be nil.') end if @name.nil? invalid_properties.push('invalid value for "name", name cannot be nil.') end if @id.nil? invalid_properties.push('invalid value for "id", id cannot be nil.') end if @extension.nil? invalid_properties.push('invalid value for "extension", extension cannot be nil.') end if @object_key.nil? invalid_properties.push('invalid value for "object_key", object_key cannot be nil.') end invalid_properties end |
#to_body ⇒ Hash
to_body is an alias to to_hash (backward compatibility)
397 398 399 |
# File 'lib/songtradr_api_client_ruby/models/file_small_dto.rb', line 397 def to_body to_hash end |
#to_hash ⇒ Hash
Returns the object in the form of hash
403 404 405 406 407 408 409 410 411 412 413 414 415 |
# File 'lib/songtradr_api_client_ruby/models/file_small_dto.rb', line 403 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = self.send(attr) if value.nil? is_nullable = self.class.openapi_nullable.include?(attr) next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}")) end hash[param] = _to_hash(value) end hash end |
#to_s ⇒ String
Returns the string representation of the object
391 392 393 |
# File 'lib/songtradr_api_client_ruby/models/file_small_dto.rb', line 391 def to_s to_hash.to_s end |
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid
243 244 245 246 247 248 249 250 251 252 253 254 255 256 257 |
# File 'lib/songtradr_api_client_ruby/models/file_small_dto.rb', line 243 def valid? warn '[DEPRECATED] the `valid?` method is obsolete' return false if @folder.nil? return false if @name.nil? return false if @id.nil? return false if @extension.nil? extension_validator = EnumAttributeValidator.new('String', ["mp3", "wav", "flac"]) return false unless extension_validator.valid?(@extension) return false if @object_key.nil? inference_status_validator = EnumAttributeValidator.new('String', ["processing", "error", "done", "not_started"]) return false unless inference_status_validator.valid?(@inference_status) fingerprint_status_validator = EnumAttributeValidator.new('String', ["processing", "error", "found", "not_found", "not_started"]) return false unless fingerprint_status_validator.valid?(@fingerprint_status) true end |